==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-textedit/i18n/l-te_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ColorDialog</name>
    <message>
        <location filename="../ColorDialog.ui" line="14"/>
        <source>Customize Colors</source>
        <translation>Színek testreszabása</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="24"/>
        <source>Item Type</source>
        <translation>Elem típusa</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="29"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="34"/>
        <source>Sample</source>
        <translation>Minta</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="44"/>
        <location filename="../ColorDialog.cpp" line="55"/>
        <source>Select Color</source>
        <translation>Szín kiválasztása</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="64"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="71"/>
        <source>Apply</source>
        <translation>Alkalmaz</translation>
    </message>
</context>
<context>
    <name>DnDTabBar</name>
    <message>
        <location filename="../DnDTabBar.h" line="43"/>
        <source>Detach Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="17"/>
        <source>MainWindow</source>
        <translation>Főablak</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="66"/>
        <source>Find the previous match</source>
        <translation>Előző találat keresése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="69"/>
        <location filename="../MainUI.ui" line="82"/>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="146"/>
        <location filename="../MainUI.ui" line="158"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="168"/>
        <source>Find:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="79"/>
        <source>Find the next match</source>
        <translation>Következő találat keresése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Replace:</source>
        <translation>Csere:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Match case</source>
        <translation>Kis- és nagybetű különbözik</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="130"/>
        <source>Replace next match</source>
        <translation>A következő találat cseréje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="143"/>
        <source>Replace all matches (to end of document)</source>
        <translation>Minden egyezés cseréje (a dokumentum végéig)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="155"/>
        <source>Hide the find/replace options</source>
        <translation>Keresés/csere opciók elrejtése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="196"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="209"/>
        <source>View</source>
        <translation>Nézet</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="213"/>
        <source>Syntax Highlighting</source>
        <translation>Szintaxiskiemelés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="220"/>
        <source>Tabs Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="237"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="252"/>
        <source>toolBar</source>
        <translation>Eszköztár</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="278"/>
        <source>Show Line Numbers</source>
        <translation>Sorszámozás megjelenítése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="283"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="288"/>
        <location filename="../MainUI.cpp" line="188"/>
        <source>New File</source>
        <translation>Új fájl</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="299"/>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="302"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="310"/>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="313"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="321"/>
        <source>Save File As</source>
        <translation>Fájl mentése másként</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="326"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="329"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="337"/>
        <source>Close File</source>
        <translation>Fájl bezárása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="348"/>
        <source>Customize Colors</source>
        <translation>Színek testreszabása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="359"/>
        <source>Wrap Lines</source>
        <translation>Sorok tördelése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="364"/>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="367"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="375"/>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="378"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Show Popup Warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="395"/>
        <location filename="../MainUI.ui" line="398"/>
        <source>Show warnings about unsaved changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="417"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="425"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="62"/>
        <source>Text Editor</source>
        <translation>Szövegszerkesztő</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="195"/>
        <source>Open File(s)</source>
        <translation>Fájl(ok) megnyitása</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="195"/>
        <source>Text Files (*)</source>
        <translation>Szövegfájlok (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="366"/>
        <location filename="../MainUI.cpp" line="377"/>
        <location filename="../MainUI.cpp" line="485"/>
        <source>Lose Unsaved Changes?</source>
        <translation>Odaveszted a mentetlen változásokat ?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="366"/>
        <location filename="../MainUI.cpp" line="377"/>
        <source>This file has unsaved changes.
Do you want to close it anyway?

%1</source>
        <translation>A fájlnak mentetlen változásai vannak!
Mindenképpen bezárod ?

%1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="485"/>
        <source>There are unsaved changes.
Do you want to close the editor anyway?

%1</source>
        <translation>Mentetlen változások vannak!
Mindenképp bezárod ?

%1</translation>
    </message>
</context>
<context>
    <name>PlainTextEditor</name>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Text File (*)</source>
        <translation>Szövegfájl (*)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="318"/>
        <source>Row Number: %1, Column Number: %2</source>
        <translation>Sor száma: %1, Oszlop száma: %2</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="327"/>
        <source>The following file has been changed by some other utility. Do you want to re-load it?</source>
        <translation>A fájl egy másik program által megváltozott. Újratöltöd ?</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="329"/>
        <source>(Note: You will lose all currently-unsaved changes)</source>
        <translation>(Megjegyzés: Minden mentetlen változás elveszik!)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="333"/>
        <source>File Modified</source>
        <translation>Fájl módosítva</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-textedit/i18n/l-te_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ColorDialog</name>
    <message>
        <location filename="../ColorDialog.ui" line="14"/>
        <source>Customize Colors</source>
        <translation>Színek testreszabása</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="24"/>
        <source>Item Type</source>
        <translation>Elem típusa</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="29"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="34"/>
        <source>Sample</source>
        <translation>Minta</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="44"/>
        <location filename="../ColorDialog.cpp" line="55"/>
        <source>Select Color</source>
        <translation>Szín kiválasztása</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="64"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="71"/>
        <source>Apply</source>
        <translation>Alkalmaz</translation>
    </message>
</context>
<context>
    <name>DnDTabBar</name>
    <message>
        <location filename="../DnDTabBar.h" line="43"/>
        <source>Detach Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="63"/>
        <source>Find the previous match</source>
        <translation>Előző találat keresése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="66"/>
        <location filename="../MainUI.ui" line="79"/>
        <location filename="../MainUI.ui" line="130"/>
        <location filename="../MainUI.ui" line="143"/>
        <location filename="../MainUI.ui" line="155"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="165"/>
        <source>Find:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="76"/>
        <source>Find the next match</source>
        <translation>Következő találat keresése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="86"/>
        <source>Replace:</source>
        <translation>Csere:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="105"/>
        <source>Match case</source>
        <translation>Kis- és nagybetű különbözik</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="127"/>
        <source>Replace next match</source>
        <translation>A következő találat cseréje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="140"/>
        <source>Replace all matches (to end of document)</source>
        <translation>Minden egyezés cseréje (a dokumentum végéig)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Hide the find/replace options</source>
        <translation>Keresés/csere opciók elrejtése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="193"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="207"/>
        <source>View</source>
        <translation>Nézet</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="211"/>
        <source>Syntax Highlighting</source>
        <translation>Szintaxiskiemelés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Tabs Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="235"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="273"/>
        <source>Show Line Numbers</source>
        <translation>Sorszámozás megjelenítése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="278"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="283"/>
        <location filename="../MainUI.cpp" line="192"/>
        <source>New File</source>
        <translation>Új fájl</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="286"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="294"/>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="297"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="305"/>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="308"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="316"/>
        <source>Save File As</source>
        <translation>Fájl mentése másként</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="321"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="324"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="332"/>
        <source>Close File</source>
        <translation>Fájl bezárása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="335"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="343"/>
        <source>Customize Colors</source>
        <translation>Színek testreszabása</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="354"/>
        <source>Wrap Lines</source>
        <translation>Sorok tördelése</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="359"/>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="362"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="373"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="387"/>
        <source>Show Popup Warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="390"/>
        <location filename="../MainUI.ui" line="393"/>
        <source>Show warnings about unsaved changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="404"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="412"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="420"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="436"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="64"/>
        <source>Text Editor</source>
        <translation>Szövegszerkesztő</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="199"/>
        <source>Open File(s)</source>
        <translation>Fájl(ok) megnyitása</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="199"/>
        <source>Text Files (*)</source>
        <translation>Szövegfájlok (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="252"/>
        <source>Print Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="383"/>
        <location filename="../MainUI.cpp" line="394"/>
        <source>Lose Unsaved Changes?</source>
        <translation>Odaveszted a mentetlen változásokat ?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="383"/>
        <location filename="../MainUI.cpp" line="394"/>
        <source>This file has unsaved changes.
Do you want to close it anyway?

%1</source>
        <translation>A fájlnak mentetlen változásai vannak!
Mindenképpen bezárod ?

%1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="503"/>
        <source>Save Changes before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="503"/>
        <source>There are unsaved changes.
Do you want save them before you close the editor?

%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlainTextEditor</name>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Text File (*)</source>
        <translation>Szövegfájl (*)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="318"/>
        <source>Row Number: %1, Column Number: %2</source>
        <translation>Sor száma: %1, Oszlop száma: %2</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="327"/>
        <source>The following file has been changed by some other utility. Do you want to re-load it?</source>
        <translation>A fájl egy másik program által megváltozott. Újratöltöd ?</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="329"/>
        <source>(Note: You will lose all currently-unsaved changes)</source>
        <translation>(Megjegyzés: Minden mentetlen változás elveszik!)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="333"/>
        <source>File Modified</source>
        <translation>Fájl módosítva</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
